# database.aws.crossplane.io/v1alpha3 API Reference

Package v1alpha3 contains managed resources for AWS database services such as RDS.

This API group contains the following Crossplane resources:

* [DBSubnetGroup](#DBSubnetGroup)

## DBSubnetGroup

A DBSubnetGroup is a managed resource that represents an AWS VPC Database Subnet Group.


Name | Type | Description
-----|------|------------
`apiVersion` | string | `database.aws.crossplane.io/v1alpha3`
`kind` | string | `DBSubnetGroup`
`metadata` | [meta/v1.ObjectMeta](https://kubernetes.io/docs/reference/generated/kubernetes-api/v1.15/#objectmeta-v1-meta) | Kubernetes object metadata.
`spec` | [DBSubnetGroupSpec](#DBSubnetGroupSpec) | A DBSubnetGroupSpec defines the desired state of a DBSubnetGroup.
`status` | [DBSubnetGroupStatus](#DBSubnetGroupStatus) | A DBSubnetGroupStatus represents the observed state of a DBSubnetGroup.



## DBSubnetGroupExternalStatus

DBSubnetGroupExternalStatus keeps the state for the external resource

Appears in:

* [DBSubnetGroupStatus](#DBSubnetGroupStatus)


Name | Type | Description
-----|------|------------
`groupArn` | string | The Amazon Resource Name (ARN) for the DB subnet group.
`groupStatus` | string | Provides the status of the DB subnet group.
`subnets` | [[]Subnet](#Subnet) | Contains a list of Subnet elements.
`vpcId` | string | Provides the VpcId of the DB subnet group.



## DBSubnetGroupNameReferencer

DBSubnetGroupNameReferencer is used to get a Name from another DBSubnetGroup




DBSubnetGroupNameReferencer supports all fields of:

* [core/v1.LocalObjectReference](https://kubernetes.io/docs/reference/generated/kubernetes-api/v1.15/#localobjectreference-v1-core)


## DBSubnetGroupParameters

DBSubnetGroupParameters define the desired state of an AWS VPC Database Subnet Group.

Appears in:

* [DBSubnetGroupSpec](#DBSubnetGroupSpec)


Name | Type | Description
-----|------|------------
`description` | string | The description for the DB subnet group.
`groupName` | string | The name for the DB subnet group. This value is stored as a lowercase string.
`subnetIds` | []string | The EC2 Subnet IDs for the DB subnet group.
`subnetIdRefs` | [[]*github.com/crossplaneio/stack-aws/apis/database/v1alpha3.SubnetIDReferencerForDBSubnetGroup](#*github.com/crossplaneio/stack-aws/apis/database/v1alpha3.SubnetIDReferencerForDBSubnetGroup) | SubnetIDRefs is a set of referencers that each retrieve the subnetID from the referenced Subnet
`tags` | [[]Tag](#Tag) | A list of tags. For more information, see Tagging Amazon RDS Resources (http://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_Tagging.html) in the Amazon RDS User Guide.



## DBSubnetGroupSpec

A DBSubnetGroupSpec defines the desired state of a DBSubnetGroup.

Appears in:

* [DBSubnetGroup](#DBSubnetGroup)




DBSubnetGroupSpec supports all fields of:

* [v1alpha1.ResourceSpec](../crossplane-runtime/core-crossplane-io-v1alpha1.md#resourcespec)
* [DBSubnetGroupParameters](#DBSubnetGroupParameters)


## DBSubnetGroupStatus

A DBSubnetGroupStatus represents the observed state of a DBSubnetGroup.

Appears in:

* [DBSubnetGroup](#DBSubnetGroup)




DBSubnetGroupStatus supports all fields of:

* [v1alpha1.ResourceStatus](../crossplane-runtime/core-crossplane-io-v1alpha1.md#resourcestatus)
* [DBSubnetGroupExternalStatus](#DBSubnetGroupExternalStatus)


## Subnet

Subnet represents a aws subnet

Appears in:

* [DBSubnetGroupExternalStatus](#DBSubnetGroupExternalStatus)


Name | Type | Description
-----|------|------------
`subnetID` | string | Specifies the identifier of the subnet.
`subnetStatus` | string | Specifies the status of the subnet.



## SubnetIDReferencerForDBSubnetGroup

SubnetIDReferencerForDBSubnetGroup is an attribute referencer that resolves SubnetID from a referenced Subnet




SubnetIDReferencerForDBSubnetGroup supports all fields of:

* github.com/crossplaneio/stack-aws/apis/network/v1alpha3.SubnetIDReferencer


## Tag

Tag defines a tag

Appears in:

* [DBSubnetGroupParameters](#DBSubnetGroupParameters)


Name | Type | Description
-----|------|------------
`key` | string | Key is the name of the tag.
`value` | string | Value is the value of the tag.



This API documentation was generated by `crossdocs`.